/**
	$Id $

	Copyright (C) 2014 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.skin;

import net.sf.basedb.clients.web.extensions.DynamicActionAttributes;
import net.sf.basedb.clients.web.taglib.Page;
import net.sf.basedb.util.extensions.Action;

/**
	Action for adding skins to BASE. Extensions are invoked on every page
	request. The page type is available (as an integer from 
	{@link Page}#PAGE_TYPE_* constants) in the context attribute "page-type".
	
	Actions are recommended to have an "ID" value, in which case a hidden 'div' 
	section is included with all dynamic attributes set on the action.
	
	Scripts and style sheets that are set by the action factory are included as
	usual. Since 'favicon' can't be modified via css this is the only other
	property that is included in this interface. Note that the first extension
	that sets a favicon "wins".

	@author nicklas
	@since 3.4
*/
public interface SkinAction
	extends Action
{

	/**
		Get the ID of the extension. Optional, but required to generate a &lt;div&gt; tag
		with dynamic attributes (if the actions implements the {@link DynamicActionAttributes}
		interface).
	*/
	public String getId();
	
	/**
		Get the full path to a favicon for the BASE site.
	*/
	public String getFavicon();
	
	/**
		Remap images to another location. Use {@link ImageRemapper#map(String, String)}
		to re-map an image from a source location to a destination location. Note that
		this method is not called on every use of the skin, but only after
		something has changed due to installation/uninstallation or enabling/disabled
		skins. The re-mapped images are then cached.
	*/
	public void remapImages(ImageRemapper mapper);
	
}
