/**
	$Id:ButtonAction.java 4187 2008-03-20 11:15:25Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.toolbar;

import net.sf.basedb.clients.web.extensions.UnsafeScriptable;
import net.sf.basedb.util.extensions.Action;

/**
	Actions represented as buttons in a toolbar.

	@author nicklas
	@version 2.7
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
 */
@UnsafeScriptable
public interface ButtonAction
	extends Action
{
	
	/**
		ID attribute of the main button tag. You need to set
		this value to reference the button in a javascript.
		@return The ID, or null
	*/
	public String getId();

	/**
		Class attribute of the main button tag. The
		default value is "button".
		@return Class attribute, or null to use the default "button"
	*/
	public String getClazz();
	
	/**
		Extra CSS style attributes that will be added to the
		<code>style</code> attribute of the main button tag.
		@return Style attributes, or null
	*/
	public String getStyle();
	
	
	/**
		Get the title of the button. 
	*/
	public String getTitle();
	
	/**
		A tooltip that is shown as a yellow popup when the 
		user points the mouse at the button.
		@return The tooltip or null to not display any tooltip
	*/
	public String getTooltip();
	
	/**
		Get a reference to an image that will be displayed in the menu.
		It is recommended that the image is 16x16 pixels to
		line up with the other icons used by the BASE.
		
		@return A reference to an image, or null if no image should
			be used
	*/
	public String getIcon();
	
	/**
		If the button should be enabled or disabled.
	*/
	public boolean isEnabled();
	
	/**
		If the button should be visible or not.
	*/
	public boolean isVisible();
	
	/**
		A javascript action that is executed when the user clicks on 
		the button. 
		
		@return The javascript action
		@deprecated In BASE 3.3. Use an ID instead and attach event handler with javascript
	*/
	@Deprecated
	public String getOnClick();

	/**
		Get the tab index used to control focus order when tabbing. Use
		-1 to disable.
		@since 3.2
	*/
	public int getTabIndex();
}
