/*
	$Id: Headers.java 6603 2014-11-18 10:28:50Z nicklas $

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.taglib.table;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;

import net.sf.basedb.clients.web.taglib.StylableTag;

/**
	Container tag for header rows in a table.  It starts a new &lt;tbody&gt; section
	of the table. The default class is "headers".

	<p>
	<b>Syntax:</b>
	<pre>
   &lt;tbl:headers&gt;
      &lt;tbl:headerrow ... &gt;
   &lt;/tbl:headers&gt;
</pre>

	@author Nicklas
	@since 3.1
*/
public class Headers
	extends StylableTag
{

	private static final long serialVersionUID = -2393116160899885910L;
	
	private Table table;
	
	public Headers()
	{
		super("headers bg-filled-100");
	}
	
	Table getTable()
	{
		return table;
	}
	
	/*
		Display methods
	*/
	@Override
	public int doStartTag()
		throws JspException
	{
		table = (Table)findAncestorWithClass(this, Table.class);

		StringBuilder sb = new StringBuilder();
		sb.append("<thead");
		addIdAndStyles(sb);
		addDynamicAttributes(sb);
		sb.append(">\n");
		try
		{
			pageContext.getOut().print(sb.toString());
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag()
		throws JspException
	{
		StringBuilder sb = new StringBuilder();
		sb.append("</thead>\n");
		try
		{
			pageContext.getOut().print(sb.toString());
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return EVAL_PAGE;
	}
}

