/*
	$Id: AuthenticationInformation.java 6425 2014-02-26 10:33:37Z nicklas $

	Copyright (C) 2005 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.authentication;

/**
	Objects of this class are returned by the 
	{@link Authenticator#authenticate(String, String)}
	method and contains information about the authenticated
	user. The only required fields are {@link #id} and {@link #login}.
	The <code>id</code> may or may not be the same as the <code>login</code>, 
	but must be a unique string identifying the user.
	<p>
	If the implementation supports extra information, ie. the call to
	{@link Authenticator#supportsExtraInformation()}
	returns TRUE, the other fields may also contain information.
	
	@author Nicklas
	@version 2.0
	@base.modified $Date: 2014-02-26 11:33:37 +0100 (on, 26 feb 2014) $
	@deprecated In 3.3, use {@link AuthenticatedUser} instead
*/
@Deprecated
public class AuthenticationInformation
{
	/**
		TRUE if the extra information has been provided, FALSE if not.
		@since 3.3
	*/
	public final boolean hasExtraInfo;
	
	/**
		A unique id for the user in the authentication system.
	*/
	public final String id;

	/**
		The login for the user. May be the same or different from the
		<code>id</code>.
	*/
	public final String login;

	/**
		The full name of the user.
	*/
	public final String name;

	/**
		The organisation of the user.
	*/
	public final String organisation;

	/**
		The postal address to the user.
	*/
	public final String address;

	/**
		The phone number to the user.
	*/
	public final String phone;

	/**
		The fax number to the user.
	*/
	public final String fax;

	/**
		The email address to the user.
	*/
	public final String email;

	/**
		An URL to the user homepage (or similar).
	*/
	public final String url;

	/**
		A description of the user.
	*/
	public final String description;

	/**
		Creates a new <code>AuthenticationInformation</code> object without
		extra information.
		@param login The {@link #login} name
		@param id The unique {@link #id} of the user
	*/
	public AuthenticationInformation(String login, String id)
	{
		this(login, id, null, null, null, null, null, null, null, null);
	}

	/**
		Creates a new <code>AuthenticationInformation</code> object with extra
		information.
		@param login The {@link #login} name
		@param id The unique {@link #id} of the user
		@param name The {@link #name} of the user
		@param organisation The {@link #organisation} of the user
		@param address The {@link #address} of the user
		@param phone The {@link #phone} of the user
		@param fax The {@link #fax} of the user
		@param email The {@link #email} of the user
		@param url The {@link #url} of the user
		@param description The {@link #description} of the user
		@throws NullPointerException If the login or id is null
	*/
	public AuthenticationInformation
	(
		String login,
		String id,
		String name,
		String organisation,
		String address,
		String phone,
		String fax,
		String email,
		String url,
		String description
	)
	{
		if (id == null) throw new NullPointerException("id");
		if (login == null) throw new NullPointerException("login");
		this.login = login;
		this.id = id;
		this.name = name;
		this.organisation = organisation;
		this.address = address;
		this.phone = phone;
		this.fax = fax;
		this.email = email;
		this.url = url;
		this.description = description;
		this.hasExtraInfo = !allNull(name, organisation, address, phone, fax, email, url, description);
	}

	
	private static boolean allNull(Object... objects)
	{
		for (Object o : objects)
		{
			if (o != null) return false;
		}
		return true;
	}
}
