/*
	$Id: ExtractData.java 6671 2014-12-19 08:16:38Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This represents an extract.

	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.Extract
	@see <a href="../../../../../../html/developer/api/data_api.biomaterials.html">Developer documentation: Biomaterials LIMS</a>
	@base.modified $Date: 2014-12-19 09:16:38 +0100 (fr, 19 dec 2014) $
	@hibernate.subclass discriminator-value="3" lazy="true"
*/
public class ExtractData
	extends MeasuredBioMaterialData
{

	public ExtractData()
	{}

	private TagData tag;
	/**
		The tag used for tagging the extract so that it can be tracked on physical bioassays. 
		@hibernate.many-to-one column="`label_id`" not-null="false" outer-join="false"
		@since 3.0
	*/
	public TagData getTag()
	{
		return tag;
	}
	public void setTag(TagData tag)
	{
		this.tag = tag;
	}
	
	private Set<RawBioAssayData> rawBioAssays;
	/**
		This is the inverse end. 
		@see RawBioAssayData#getParentExtract()
		@since 3.0
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`extract_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.RawBioAssayData"
	*/
	Set<RawBioAssayData> getRawBioAssays()
	{
		return rawBioAssays;
	}
	void setRawBioAssays(Set<RawBioAssayData> rawBioAssays)
	{
		this.rawBioAssays = rawBioAssays;
	}
	
	private Set<DerivedBioAssayData> derivedBioAssays;
	/**
		This is the inverse end. 
		@see DerivedBioAssayData#getExtract()
		@since 3.4
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`extract_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.DerivedBioAssayData"
	*/
	Set<DerivedBioAssayData> getDerivedBioAssays()
	{
		return derivedBioAssays;
	}
	void setDerivedBioAssays(Set<DerivedBioAssayData> derivedBioAssays)
	{
		this.derivedBioAssays = derivedBioAssays;
	}

}
