/*
	$Id: PlateEventTypeData.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class holds information about a plate event type.

	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.PlateEventType
	@see <a href="../../../../../../html/developer/api/data_api.plates.html">Developer documentation: Array LIMS (plates)</a>
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fr, 14 sep 2012) $
	@hibernate.class table="`PlateEventTypes`" lazy="false"
*/
public class PlateEventTypeData
	extends BasicData
	implements NameableData, RemovableData
{

	public PlateEventTypeData()
	{}
	
	/*
		From the NameableData interface
		-------------------------------------------
	*/
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	@Override
	public void setName(String name)
	{
		this.name = name;
	}
	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	// -------------------------------------------
	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private boolean removed;
	@Override
	public boolean isRemoved()
	{
		return removed;
	}
	@Override
	public void setRemoved(boolean removed)
	{
		this.removed = removed;
	}
	// -------------------------------------------

	private PlateTypeData plateType;
	/**
		The plate type this event type belongs to.
		@see PlateTypeData#getEventTypes()
		@hibernate.many-to-one column="`platetype_id`" not-null="true" outer-join="false" update="false"
	*/
	public PlateTypeData getPlateType()
	{
		return plateType;
	}
	public void setPlateType(PlateTypeData plateType)
	{
		this.plateType = plateType;
	}

	private int ordinal;
	/**
		The ordinal of this event type among all event types defined for the plate type.
		@hibernate.property column="`ordinal`" type="int" not-null="true" 
	*/
	public int getOrdinal()
	{
		return ordinal;
	}
	public void setOrdinal(int ordinal)
	{
		this.ordinal = ordinal;
	}
	
	private ItemSubtypeData protocolType;
	/**
		The protocol type that events of this event type should pick their protocols from.
		@hibernate.many-to-one column="`protocolsubtype_id`" outer-join="false" not-null="false" 
	*/
	public ItemSubtypeData getProtocolType()
	{
		return protocolType;
	}
	public void setProtocolType(ItemSubtypeData protocolType)
	{
		this.protocolType = protocolType;
	}
	
	private Set<PlateEventData> plateEvents;
	/**
		This is the inverse end.
		@see PlateEventData#getPlateEventType()
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`plateeventtype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.PlateEventData"
	*/
	Set<PlateEventData> getPlateEvents()
	{
		return plateEvents;
	}
	void setPlateEvents(Set<PlateEventData> plateEvents)
	{
		this.plateEvents = plateEvents;
	}

}
