/*
	$Id: TextParameterValueData.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Johan Enell, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.List;
import java.util.ArrayList;

/**
	Text parameter value.

	@author Samuel
	@version 2.0
	@see <a href="../../../../../../html/developer/api/data_api.parameters.html">Developer documentation: Parameters</a>
	@hibernate.subclass discriminator-value="6"
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fr, 14 sep 2012) $
*/
public class TextParameterValueData
	extends ParameterValueData<String>
{
	public TextParameterValueData()
	{}
	
	public TextParameterValueData(String... values)
	{
		super(values);
	}
	
	/**
		@return 6 (Type.TEXT)
		@since 2.16
	*/
	@Override
	public int getValueType()
	{
		return 6;
	}
	
	private List<String> values;
	/**
		@hibernate.bag table="`TextValues`" lazy="true" cascade="all"
		@hibernate.collection-key column="`id`"
		@hibernate.collection-element column="`value`" type="text" not-null="true"
	*/
	@Override
	public List<String> getValues()
	{
		if (values == null)
		{
			values = new ArrayList<String>();
		}
		return values;
	}
	@Override
	void setValues(List<String> values)
	{
		this.values = values;
	}

	@Override
	public String toString()
	{
		return values.toString();
	}	
}
