/**
	$Id: AboutBean.java 6408 2014-01-31 07:56:36Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import net.sf.basedb.core.plugin.About;

/**
	An implementation of the {@link About} interface, which
	complements all getter methods with setter methods.
	
	@author nicklas
	@version 2.7
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
*/
public class AboutBean 
	implements About, ExtendedAbout
{

	private String name;
	private String description;
	private String version;
	private String minBaseVersion;
	private String maxBaseVersion;
	private String copyright;
	private String contact;
	private String email;
	private String url;
	private Map<String, String> attributes;
	
	/**
		Create a new empty about instance.
	*/
	public AboutBean()
	{}
	
	@Override
	public String getContact()
	{
		return contact;
	}
	public void setContact(String contact)
	{
		this.contact = contact;
	}
	
	@Override
	public String getCopyright() 
	{
		return copyright;
	}
	public void setCopyright(String copyright)
	{
		this.copyright = copyright;
	}
	@Override
	public String getDescription() 
	{
		return description;
	}
	public void setDescription(String description)
	{
		this.description = description;
	}
	
	@Override
	public String getEmail() 
	{
		return email;
	}
	public void setEmail(String email)
	{
		this.email = email;
	}

	@Override
	public String getName() 
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}

	@Override
	public String getUrl() 
	{
		return url;
	}
	public void setUrl(String url)
	{
		this.url = url;
	}

	@Override
	public String getVersion() 
	{
		return version;
	}
	public void setVersion(String version)
	{
		this.version = version;
	}

	@Override
	public String getMinBaseVersion() 
	{
		return minBaseVersion;
	}
	public void setMinBaseVersion(String version)
	{
		this.minBaseVersion = version;
	}

	@Override
	public String getMaxBaseVersion() 
	{
		return maxBaseVersion;
	}
	public void setMaxBaseVersion(String version)
	{
		this.maxBaseVersion = version;
	}


	@Override
	public String getAttribute(String name)
	{
		return attributes == null ? null : attributes.get(name);
	}
	
	@Override
	public Collection<String> getAttributeNames() 
	{
		return attributes == null ? null : attributes.keySet();
	}

	/**
		Set an attribute for the given name.
		@since 3.3
	*/
	public void setAttribute(String name, String value)
	{
		if (attributes == null) attributes = new HashMap<String, String>();
		attributes.put(name, value);
	}

	
	/**
		Copy information from antoher <code>About</code> object
		to this one.
		@param from The object to copy from
		@param overwrite TRUE copy all values, FALSE
			to only copy if the existing value is null
	*/
	public void copy(About from, boolean overwrite)
	{
		if (from == null) return;
		name = overwrite || name == null ? from.getName() : name;
		description = overwrite || description == null ? from.getDescription() : description;
		version = overwrite || version == null ? from.getVersion() : version;
		minBaseVersion = overwrite || minBaseVersion == null ? from.getMinBaseVersion() : minBaseVersion;
		maxBaseVersion = overwrite || maxBaseVersion == null ? from.getMaxBaseVersion() : maxBaseVersion;
		copyright = overwrite || copyright == null ? from.getCopyright() : copyright;
		contact = overwrite || contact == null ? from.getContact() : contact;
		email = overwrite || email == null ? from.getEmail() : email;
		url = overwrite || url == null ? from.getUrl() : url;
		
		if (from instanceof ExtendedAbout)
		{
			ExtendedAbout xtFrom = ((ExtendedAbout)from);
			Collection<String> otherAttributes = xtFrom.getAttributeNames();
			if (otherAttributes != null && otherAttributes.size() > 0)
			{
				if (attributes == null) attributes = new HashMap<String, String>();
				for (String name : otherAttributes)
				{
					if (overwrite || !attributes.containsKey(name))
					{
						attributes.put(name, xtFrom.getAttribute(name));
					}
				}
			}
		}
		
	}

}
