/**
	$Id: ObjectKey.java 5606 2011-04-14 07:45:23Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.manager;

/**
	Instances of object keys should be something that uniquely
	identifies an object that has been defined by an extension.
	Object keys are mainly used to lookup in which file a
	certain object has been defined 
	(see {@link ExtensionsManager#getFileByObjectKey(ObjectKey)})
	and/or to get information about the object itself 
	(see {@link ExtensionsFile#getObjectForKey(ObjectKey)})
	<p>
	
	It is up to the actual implementations to decide what actually 
	makes up a key that can be used to identify an object. Implementors
	of this interface should implement <code>equals()</code> and
	<code>hashCode()</code> methods to only match with it's
	own class. Implementations should be immutable.
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-14 09:45:23 +0200 (to, 14 apr 2011) $
	@see ExtensionsManager#getFileByObjectKey(ObjectKey)
	@see ExtensionsFile#getObjectForKey(ObjectKey)
	@param <O> The type of object that the key references
*/
public interface ObjectKey<O>
{
	/**
		Get a string description of the key that is suitable for use
		in (error) messages to users.
	*/
	public String toDescription();
}
