/*
	$Id: Mapper.java 4515 2008-09-11 20:08:14Z jari $
	
	Copyright (C) 2006 Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.
	
	BASE is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.parser;

import net.sf.basedb.util.parser.FlatFileParser.Data;

/**
	Represents a mapping expression that gets a single value from
 	a line of data. A typical mapping expression
	holds a reference to the column number or name, for example:
	<pre class="code">
\1\
\row\
Row: \row\, Col:\col\
=2 * col('Radius')
</pre>

	The actual syntax for the mapping string depends on the parser used.

	@author Nicklas
 	@version 2.0
 	@see net.sf.basedb.util.parser.FlatFileParser#getMapper(String)
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (to, 11 sep 2008) $
*/
public interface Mapper
{
	/**
		Get the value for the line of data.
		@param data The line of data
		@return A string value
	*/
	public String getValue(Data data);
	
	/**
		Get the value for the line of data as an integer.

		@param data The line of data
		@return The value as an integer
		@throws NumberFormatException If the value can't be parsed as an integer
	*/
	public Integer getInt(Data data);
	
	/**
		Get the value for the line of data as a float.
	
		@param data The line of data
		@return The value as a float
		@throws NumberFormatException If the value can't be parsed as a float
	*/
	public Float getFloat(Data data);


}
