/*
	$Id: TestAnnotationFlatFileImporter.java 6100 2012-09-04 08:43:21Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/

import net.sf.basedb.core.AnnotationType;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.File;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.Job;
import net.sf.basedb.core.ParameterType;
import net.sf.basedb.core.Permission;
import net.sf.basedb.core.PluginConfigurationRequest;
import net.sf.basedb.core.PluginDefinition;
import net.sf.basedb.core.PluginParameter;
import net.sf.basedb.core.PluginResponse;
import net.sf.basedb.core.Quantity;
import net.sf.basedb.core.RequestInformation;
import net.sf.basedb.core.SystemItems;
import net.sf.basedb.core.Type;
import net.sf.basedb.core.plugin.GuiContext;
import net.sf.basedb.core.plugin.Response;


public class TestAnnotationFlatFileImporter
{
	static boolean ok = true;

	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing annotation import using plugin");
		// Create annotation types, samples and upload file
		
		int timeQuantityId = SystemItems.getId(Quantity.TIME);
		int hoursId = TestUnit.test_load_by_symbol(timeQuantityId, "h");
		
		int timeId = TestAnnotationType.test_create("Time (hours)", Type.INT, hoursId, null, 25, Item.SAMPLE, 1, null, false);
		int ageId = TestAnnotationType.test_create("Age (years)", Type.INT, 0, null, 100, Item.SAMPLE, 1, null, false);
		int commentId = TestAnnotationType.test_create("Comment", Type.STRING, 0, null, 20, Item.SAMPLE, 0, null, false);
		int enumId = TestAnnotationType.test_create("Subtype", Type.STRING, 0, null, null, 
			Item.SAMPLE, 1, new String[] { "alfa", "beta", "gamma" }, false);
		int timestampId = TestAnnotationType.test_create("Timestamp", Type.TIMESTAMP, 0, null, null, Item.SAMPLE, 1, null, false);

		int sample1 = TestSample.test_create(0, "Sample #1", 0, false);
		int sample2 = TestSample.test_create(0, "Sample #2", 0, false);
		int sample3 = TestSample.test_create(0, "Sample #3", 0, false);
		int sample4 = TestSample.test_create(0, "Sample #4", 0, false);
		int sampleDup1 = TestSample.test_create(0, "Sample dup", 0, false);
		int sampleDup2 = TestSample.test_create(0, "Sample dup", 0, false);
		
		TestAnnotation.test_annotatate(Item.SAMPLE, sample4, ageId, 0, 2);
		TestAnnotation.test_annotatate(Item.SAMPLE, sample4, enumId, 0, "gamma");
		TestAnnotation.test_annotatate(Item.SAMPLE, sample4, commentId, 0, "A comment from code");
		
		int fileId = TestFile.test_create("data/test.annotation.import.txt", false, false);
		
		// Create job
		int pluginDefinitionId  = TestPluginDefinition.test_get("net.sf.basedb.plugins.AnnotationFlatFileImporter");
		int jobId = test_create_job(pluginDefinitionId, fileId, timeId, ageId, enumId, timestampId, commentId, commentId);
		
		// Execute job
		ok &= TestJob.test_execute(jobId, false);
		
		// Test: list the result
		TestAnnotation.test_list_annotations(Item.SAMPLE, sample1, 5);
		TestAnnotation.test_list_annotations(Item.SAMPLE, sample2, 3);
		TestAnnotation.test_list_annotations(Item.SAMPLE, sample3, 3);
		TestAnnotation.test_list_annotations(Item.SAMPLE, sample4, 3);
		TestAnnotation.test_list_annotations(Item.SAMPLE, sampleDup1, 5);
		TestAnnotation.test_list_annotations(Item.SAMPLE, sampleDup2, 5);
		ok &= TestAnnotation.ok;
		
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();

		TestJob.test_delete(jobId);
		TestFile.test_delete(fileId);
		TestSample.test_delete(sample1);
		TestSample.test_delete(sample2);
		TestSample.test_delete(sample3);
		TestSample.test_delete(sample4);
		TestSample.test_delete(sampleDup1);
		TestSample.test_delete(sampleDup2);
		TestAnnotationType.test_delete(commentId);
		TestAnnotationType.test_delete(ageId);
		TestAnnotationType.test_delete(timeId);
		TestAnnotationType.test_delete(enumId);
		TestAnnotationType.test_delete(timestampId);

		write("++Testing annotation import using plugin "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static int test_create_job(int pluginDefinitionId, int fileId, int... annotationTypes)
	{
		if (pluginDefinitionId == 0 || fileId == 0 || !TestUtil.hasPermission(Permission.CREATE, Item.JOB)) return 0;
		int id = 0;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();

			PluginDefinition plugin = PluginDefinition.getById(dc, pluginDefinitionId);
			Job j = Job.getNew(dc, plugin, null, null);
			j.setName("Import annotations");
			
			// Step 1 - file and parser regular expressions
			PluginConfigurationRequest request = j.configure(new GuiContext(Item.SAMPLE, GuiContext.Type.LIST));
			request.getRequestInformation();
			request.setParameterValue("file", File.getById(dc, fileId));
			request.setParameterValue("dataSplitterRegexp", "\\t");
			request.setParameterValue("dataHeaderRegexp", "Name.*");
			request.setParameterValue("nameColumnMapping", "\\Name\\");
			request.setParameterValue("ignoreRegexp", "#.*");
			request.setParameterValue("timestampFormat", "yyyy-MM-dd HH:mm");
				
			PluginResponse response = request.invoke();
			if (response.getStatus() != Response.Status.CONTINUE)
			{
				throw new BaseException(response.getMessage());
			}

			// Step 2 - mapping to annotation types
			request = response.getNextRequest();
			request.getRequestInformation();
			for (int i = 0; i < annotationTypes.length; ++i)
			{
				request.setParameterValue("columnMapping." + (i+1), AnnotationType.getById(dc, annotationTypes[i]));
			}
			response = request.invoke();
			
			if (response.getStatus() != Response.Status.CONTINUE)
			{
				throw new BaseException(response.getMessage());
			}
			
			// Step 3 - other options and error handling
			request = response.getNextRequest();
			request.getRequestInformation();
			request.setParameterValue("replaceExisting", true);
			request.setParameterValue("removeExisting", true);
			request.setParameterValue("addToUnlimited", true);
			request.setParameterValue("defaultError", "fail");
			request.setParameterValue("itemNotFoundError", "skip");
			request.setParameterValue("stringTooLongError", "crop");
			request.setParameterValue("numberFormatError", "skip");
			request.setParameterValue("dateFormatError", "skip");
			request.setParameterValue("numberOutOfRangeError", "skip");
			request.setParameterValue("invalidEnumError", "skip");
			request.setParameterValue("tooManyValuesError", "crop");
			request.setParameterValue("multipleItemsFoundError", "all");
			response = request.invoke();
			
			if (response.getStatus() == Response.Status.DONE)
			{
				response.saveParameters(dc);
				dc.saveItem(j);
				dc.commit();
			}
			else
			{
				throw new BaseException(response.getMessage());
			}
			id = j.getId();
			write("--Create job for annotation import OK");
		}
		catch (Throwable ex)
		{
			write("--Create job for annotation import FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
		return id;
	}
	
	static void write(String message)
	{
		System.out.println(message);
	}


	static void write_request_information(RequestInformation ri)
	{
		if (TestUtil.getSilent()) return;

		write("Request information for command: "+ri.getCommand());
		write("\tTitle:\t"+ri.getTitle());
		write("\tDescription:\t"+ri.getDescription());
		for (PluginParameter<?> pp : ri.getParameters())
		{
			ParameterType pt = pp.getParameterType();
			System.out.println("\tParameter:\t"+pp.getName() + "\t" + pp.getLabel() + "\t" + pt );
		}
	}
}

