<%-- $Id: edit_event.jsp 6306 2013-08-13 13:15:33Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.BioMaterialEvent"
	import="net.sf.basedb.core.MeasuredBioMaterial"
	import="net.sf.basedb.core.Protocol"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.formatter.FormatterSettings"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Date"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.BIOMATERIALEVENT;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final Item bioMaterialType = Item.valueOf(request.getParameter("biomaterial_type"));
final int bioMaterialId = Values.getInt(request.getParameter("biomaterial_id"));
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	String title = null;
	BioMaterialEvent event = null;
	MeasuredBioMaterial bioMaterial = null;
	Date eventDate = null;
	
	boolean readCurrentProtocol = true;
	Protocol currentProtocol = null;

	// Load recently used items
	List<Protocol> recentProtocols = (List<Protocol>)cc.getRecent(dc, Item.PROTOCOL);
	
	if (itemId == 0)
	{
		title = "Create event";
		cc.removeObject("item");
		eventDate = (Date)cc.getPropertyObject("eventDate");
	}
	else
	{
		event = BioMaterialEvent.getById(dc, itemId);
		event.checkPermission(Permission.WRITE);
		eventDate = event.getEventDate();
		title = "Edit event";
		cc.setObject("item", event);
		
		try
		{
			currentProtocol = event.getProtocol();
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentProtocol = false;
		}
	}
	
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	String dateFormat = FormatterSettings.getDateFormat(sc);
	String jsDateFormat = HTML.javaScriptEncode(dateFormat);
	String htmlDateFormat = HTML.encodeTags(dateFormat);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), event);
	ExtensionsInvoker invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,~events.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%></h1>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="event">
		<input type="hidden" name="cmd" value="UpdateItem">
		<input type="hidden" name="biomaterial_type" value="<%=bioMaterialType.name()%>">
		<input type="hidden" name="biomaterial_id" value="<%=bioMaterialId%>">

		<t:tabcontrol id="settings" 
			subclass="content dialogtabcontrol"
			position="bottom" remember="<%=event != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Event">
			<table class="fullform input100">
			<tr>
				<th>Event date</th>
				<td>
					<table>
					<tr>
					<td>
						<input class="text auto-init" data-auto-init="<%=event == null ? "focus-select" : "focus" %>"
							style="width: 15em;" type="text" name="event_date" id="event_date"
							value="<%=HTML.encodeTags(dateFormatter.format(eventDate == null ? new Date() : eventDate))%>" 
							maxlength="20" title="Enter date in format: <%=htmlDateFormat%>">
						&nbsp;
					</td>
					<td>
						<base:calendar textarea="event_date" title="Event date" />
					</td>
					</tr>
					</table>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>Used quantity</th>
				<td><input class="text" style="width: 15em;" type="text" name="used_quantity" 
					id="usedQuantity"
					value="<%=Values.formatNumber(event == null ? null : event.getUsedQuantity(), -1)%>"
					maxlength="10"> (µg)</td>
				<td></td>
			</tr>
			<tr>
				<th>Protocol</th>
				<td>
					<base:select 
						id="protocol_id"
						clazz="selectionlist"
						required="false"
						current="<%=currentProtocol%>"
						denied="<%=!readCurrentProtocol%>"
						recent="<%=recentProtocols%>"
						newitem="<%=event == null%>"
					/>
				</td>
				<td></td>
			</tr>
			<tr class="dynamic">
				<th>Comment</th>
				<td>
					<textarea class="text" rows="6" name="comment" id="comment"
						><%=HTML.encodeTags(event == null ? cc.getPropertyValue("comment") : event.getComment())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="comment" title="Comment" />
				</td>
			</tr>
			</table>
		</t:tab>
		</t:tabcontrol>
		</form>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
