<%-- $Id: share.jsp 6608 2014-11-20 07:58:36Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	Configure the order and visibility of columns in a table of items.
	This page will use the TableColumn.getTableColumns(item) to retreive the
	list of all available columns for that item type and
	getSession().getSetting(item+".columns") to retreive a comma-separated
	list of the current order of visible columns.

	@param item The type of items in the table

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemKey"
	import="net.sf.basedb.core.Nameable"
	import="net.sf.basedb.core.SharedItem"
	import="net.sf.basedb.core.ProjectKey"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.MultiPermissions"
	import="net.sf.basedb.core.User"
	import="net.sf.basedb.core.Group"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemResultIterator"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.WebException"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.json.JsonUtil"
	import="net.sf.basedb.util.json.NameableConverter"
	import="org.json.simple.JSONObject"
	import="org.json.simple.JSONArray"
	import="java.util.EnumSet"
	import="java.util.Set"
	import="java.util.Map"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%!
private static final int READ_CODE = PermissionUtil.getPermissionCode(EnumSet.of(Permission.READ));
private static final int USE_CODE = PermissionUtil.getPermissionCode(EnumSet.of(Permission.USE));
private static final int WRITE_CODE = PermissionUtil.getPermissionCode(EnumSet.of(Permission.WRITE));
private static final int DELETE_CODE = PermissionUtil.getPermissionCode(EnumSet.of(Permission.DELETE));
private static final int SET_OWNER_CODE = PermissionUtil.getPermissionCode(EnumSet.of(Permission.SET_OWNER));
private static final int SET_PERMISSION_CODE = PermissionUtil.getPermissionCode(EnumSet.of(Permission.SET_PERMISSION));
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final Item itemType = Item.valueOf(request.getParameter("item_type"));
final String subContext = Values.getString(request.getParameter("subcontext"), "");

final DbControl dc = sc.newDbControl();
ItemResultIterator<User> users = null;
ItemResultIterator<Group> groups = null;
ItemResultIterator<Project> projects = null;
try
{
	final MultiPermissions mp = (MultiPermissions)sc.getCurrentContext(itemType, subContext).getObject("MultiPermissions");
	if (mp == null)
	{
		throw new WebException("popup", "Item not found", "No MultiPermissions object found for item: " + itemType);
	}

	JSONArray jsonShare = new JSONArray();

	// Query to retrieve users
	final ItemQuery<User> userQuery = mp.getUsers();
	userQuery.order(Orders.asc(Hql.property("name")));

	JSONObject jsonUsers = new JSONObject();
	jsonShare.add(jsonUsers);
	jsonUsers.put("itemType", "USER");
	jsonUsers.put("name", "Users");
	jsonUsers.put("items", JsonUtil.toArray(userQuery.iterate(dc), 
		new NameableConverter<User>()
		{
			protected void setMore(JSONObject json, User user)
			{
				Map<ItemKey, Set<Permission>> p = mp.getPermissions(user);
				int permissionCode = 0;
				String permissionString = "varying";
				if (MultiPermissions.allSame(p.values()))
				{
					Set<Permission> first = p.values().iterator().next();
					permissionCode = PermissionUtil.getPermissionCode(first);
					permissionString = PermissionUtil.translatePermissionsToString(first);
				}
				json.put("name", user.getName() + " [" + permissionString + "]");
				json.put("value", permissionCode);
			}
		}
	));
	

	// Query to retrieve groups
	final ItemQuery<Group> groupQuery = mp.getGroups();
	groupQuery.order(Orders.asc(Hql.property("name")));
	
	JSONObject jsonGroups = new JSONObject();
	jsonShare.add(jsonGroups);
	jsonGroups.put("itemType", "GROUP");
	jsonGroups.put("name", "Groups");
	jsonGroups.put("items", JsonUtil.toArray(groupQuery.iterate(dc), 
		new NameableConverter<Group>()
		{
			protected void setMore(JSONObject json, Group group)
			{
				Map<ItemKey, Set<Permission>> p = mp.getPermissions(group);
				int permissionCode = 0;
				String permissionString = "varying";
				if (MultiPermissions.allSame(p.values()))
				{
					Set<Permission> first = p.values().iterator().next();
					permissionCode = PermissionUtil.getPermissionCode(first);
					permissionString = PermissionUtil.translatePermissionsToString(first);
				}
				json.put("name", group.getName() + " [" + permissionString + "]");
				json.put("value", permissionCode);
			}
		}
	));
	
	// Query to retrieve projects
	final ItemQuery<Project> projectQuery = mp.getProjects();
	projectQuery.order(Orders.asc(Hql.property("name")));
	
	JSONObject jsonProjects = new JSONObject();
	jsonShare.add(jsonProjects);
	jsonProjects.put("itemType", "PROJECT");
	jsonProjects.put("name", "Projects");
	jsonProjects.put("items", JsonUtil.toArray(projectQuery.iterate(dc), 
		new NameableConverter<Project>()
		{
			protected void setMore(JSONObject json, Project project)
			{
				Map<ProjectKey, Set<Permission>> p = mp.getPermissions(project);
				int permissionCode = 0;
				String permissionString = "varying";
				if (MultiPermissions.allSame(p.values()))
				{
					Set<Permission> first = p.values().iterator().next();
					permissionCode = PermissionUtil.getPermissionCode(first);
					permissionString = PermissionUtil.translatePermissionsToString(first);
				}
				json.put("name", project.getName() + " [" + permissionString + "]");
				json.put("value", permissionCode);
			}
		}
	));

	JSONObject jsonTemplates = new JSONObject();
	jsonShare.add(jsonTemplates);
	jsonTemplates.put("itemType", "PERMISSIONTEMPLATE");
	jsonTemplates.put("name", "Permission templates");
	
	final boolean writePermission = true;
	
	/*
	 	Set the headline with the item's name or, 
	 	if there are more then one item, the text 'multiple item'
	*/
	String headLine = "";
	Set<SharedItem> currentItems = mp.getItems();
	if(currentItems.size() == 1)
	{
		SharedItem item = currentItems.iterator().next();  
		if(item instanceof Nameable)
		{
			headLine = "Set access permissions -- " + HTML.encodeTags(((Nameable)item).getName());
		}
		else
		{
			headLine = "Set access permissions -- " + HTML.encodeTags(item.toString());
		}
	}
	else
	{
		headLine = "Set access permissions -- Multiple items (" + currentItems.size() + ")";
	}
	boolean hasDirectory = mp.getItems(Item.DIRECTORY).size() > 0;

	%>
	<base:page type="popup" title="Set access permissions">
	<base:head scripts="linkitems-2.js,~share.js" />
	<base:body>
		<h1><%=headLine%> <base:help helpid="share.setpermissions" /></h1>
		
		<div id="page-data" class="datacontainer"
			data-read="<%=READ_CODE%>"
			data-use="<%=USE_CODE%>"
			data-write="<%=WRITE_CODE%>"
			data-delete="<%=DELETE_CODE%>"
			data-set-owner="<%=SET_OWNER_CODE%>"
			data-set-permission="<%=SET_PERMISSION_CODE%>"
			data-everyone-id="<%=SystemItems.getId(Group.EVERYONE)%>"
			data-share-to-everyone="<%=sc.hasSystemPermission(Permission.SHARE_TO_EVERYONE) ? 1 : 0%>"
			></div>
		
		<form name="share" action="submit_share.jsp">
		<input type="hidden" name="ID" value="<%=ID%>">
		<input type="hidden" name="cmd" value="Save">
		<input type="hidden" name="item_type" value="<%=itemType.name()%>">
		<input type="hidden" name="subcontext" value="<%=subContext%>">
		<input type="hidden" name="permissionTemplates" value="">
	
		<div class="content bg-filled-50 bottomborder">
		<table style="width: 100%;">
		<tr>
			<td class="padded"><b>Members</b></td>
			<td class="padded"><b>Permissions</b></td>
			<td></td>
		</tr>
		<tr style="vertical-align: top;">
			<td rowspan="2" style="padding-left: 5px; padding-right: 5px;">
				<select name="members" id="members" 
					class="auto-init" data-auto-init="link-container"
					data-initial-items="<%=HTML.encodeTags(jsonShare.toJSONString()) %>"				
					size="14" multiple style="width: calc(100% - 10px);" 
					<%=!writePermission ? "disabled" : ""%>>
				</select>
			</td>
			<td>
				<input type="checkbox" id="read" checked name="read"><label for="read">Read</label><br>
				<input type="checkbox" id="use" checked name="use"><label for="use">Use</label><br>
				<input type="checkbox" id="write" name="write"><label for="write">Write</label><br>
				<input type="checkbox" id="delete" name="delete"><label for="delete">Delete</label><br>
				<input type="checkbox" id="setOwner" name="set_owner"><label for="setOwner">Set owner</label><br>
				<input type="checkbox" id="setPermission" name="set_permission"><label for="setPermission">Set permission</label><br>
			</td>
			<td>
				<base:buttongroup vertical="true" style="width: 12em;">
					<base:button 
						id="btnAddUsers"
						subclass="leftaligned"
						title="Add&nbsp;users&hellip;" 
						tooltip="Add users"
						disabled="<%=!writePermission %>" 
						/>
					<base:button 
						id="btnAddGroups"
						subclass="leftaligned"
						title="Add&nbsp;groups&hellip;"  
						tooltip="Add groups"
						disabled="<%=!writePermission %>" 
					/>
					<base:button 
						id="btnAddProjects"
						subclass="leftaligned"
						title="Add&nbsp;projects&hellip;" 
						tooltip="Add projects"
						disabled="<%=!writePermission %>" 
						/>
					<base:button 
						id="btnAddPermissionTemplates"
						subclass="leftaligned"
						title="Templates&hellip;" 
						tooltip="Add permission templates"
						image="add.png"
						disabled="<%=!writePermission %>" 
						/>
					<base:button 
						subclass="leftaligned auto-init"
						data-auto-init="remove-link"
						data-list-id="members"
						id="btnRemove"
						title="Remove" 
						tooltip="Remove the selected items from this group"
						disabled="<%=!writePermission%>" 
					/>
				</base:buttongroup>
			</td>
		</tr>
		<tr>
			<td colspan="2">
			<%
			if (hasDirectory)
			{
				%>
				<input type="checkbox" name="recursive" value="1" id="recursive">
				<label for="recursive">Apply permissions to all subdirectories and their files</label>
				<%
			}
			%>
			</td>
		</tr>
		</table>

			<div class="messagecontainer error" id="share_disabled" style="display:none;">
				You don't have permission to change permissions for the 
				Everyone group. Please contact the server administrator
				if you think you should have that permission.
			</div>
		
		</div>
		</form>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Ok" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>

	</base:body>
	</base:page>
	<%
}
finally
{
	if (users != null) users.close();
	if (groups != null) groups.close();
	if (projects != null) projects.close();
	if (dc != null) dc.close();
}
%>
