/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var BioAssays = function()
{
	var bioassays = {};
	
	/**
		Initialize the page.
	*/
	bioassays.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', bioassays.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabActivateListener('settings.annotations', bioassays.loadAnnotationsFrame);
			TabControl.addTabActivateListener('settings.inheritedAnnotations', bioassays.loadInheritedAnnotationsFrame);
			TabControl.addTabActivateListener('settings.datafiles', bioassays.loadDataFilesFrame);
			TabControl.addTabValidator('settings.info', bioassays.validateRawBioAssay);
			
			// Platform
			Events.addEventHandler('platform', 'change', bioassays.platformOnChange);
			bioassays.platformOnChange();

			// Protocol
			Buttons.addClickHandler('protocol_id.select', bioassays.selectProtocol);
			Events.addEventHandler('protocol_id', 'base-selected', bioassays.setProtocolCallback);

			// Software
			Buttons.addClickHandler('software_id.select', bioassays.selectSoftware);
			Events.addEventHandler('software_id', 'base-selected', bioassays.setSoftwareCallback);
			
			// Parent bioassay
			Buttons.addClickHandler('bioassay_id.select', bioassays.selectBioAssay);
			Events.addEventHandler('bioassay_id', 'base-selected', bioassays.setBioAssayCallback);
			Events.addEventHandler('bioassay_id', 'change', bioassays.bioAssayOnChange);

			// Array design
			Buttons.addClickHandler('arraydesign_id.select', bioassays.selectArrayDesign);
			Events.addEventHandler('arraydesign_id', 'base-selected', bioassays.setArrayDesignCallback);
			Events.addEventHandler('arraydesign_id', 'change', bioassays.arrayDesignOnChange);

			// Extract
			Buttons.addClickHandler('extract_id.select', bioassays.selectExtract);
			Events.addEventHandler('extract_id', 'base-selected', bioassays.setExtractCallback);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'RAWBIOASSAY', 'item-id': itemId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnEditSpotImages', bioassays.editSpotImages, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
			TabControl.addTabActivateListener('main.rawdata', bioassays.viewRawData);
			TabControl.addTabActivateListener('main.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('main.overview', Overview.loadOnce);
			TabControl.addTabActivateListener('main.history', History.loadOnce);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'RAWBIOASSAY'};
			var tableAttributes = {'table-id': 'rawbioassays'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnNewExperiment', bioassays.newExperiment);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	bioassays.newExperiment = function()
	{
		if (!Table.checkIfSelected('rawbioassays'))
		{
			return;
		}
		Table.submitToPopup('rawbioassays', 'NewExperiment', 750, 500);
	}

	bioassays.editSpotImages = function()
	{
		var url = 'index.jsp?ID='+App.getSessionId();
		url += '&cmd=EditSpotImages&item_id='+Data.get('page-data', 'item-id');
		Dialogs.openPopup(url, 'EditSpotImages', 600, 400);
	}

	bioassays.viewRawData = function()
	{
		var url = 'rawdata/index.jsp?ID='+App.getSessionId();
		url += '&cmd=List&rawbioassay_id='+Data.get('page-data', 'item-id');
		location.replace(url);
	}

	bioassays.validateRawBioAssay = function()
	{
		var frm = document.forms['rawbioassay'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	// Submit the form
	bioassays.save = function()
	{
		var frm = document.forms['rawbioassay'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			Annotations.saveInheritedAnnotationsToForm(frm);
			DataFiles.writeFileActionsToForm(frm);
			frm.submit();
		}
	}
	
	bioassays.loadDataFilesFrame = function()
	{
		var frm = document.forms['rawbioassay'];
		var selected = frm.platform[frm.platform.selectedIndex];
		var platform = Data.get(selected, 'platform');
		var variant = Data.get(selected, 'variant');
		DataFiles.autoLoadEditFrame(platform ? platform : 0, variant ? variant : 0, 0);
	}

	bioassays.loadAnnotationsFrame = function()
	{
		Annotations.autoLoadEditFrame(bioassays.getProtocolId());
	}
	
	bioassays.loadInheritedAnnotationsFrame = function()
	{
		Annotations.autoLoadInheritFrame(bioassays.getParents());
	}

	bioassays.getProtocolId = function()
	{
		var frm = document.forms['rawbioassay'];
		var protocolId = 0;
		if (frm.protocol_id.length > 0 && !frm.protocol_id.disabled) 
		{
			protocolId = Math.abs(parseInt(frm.protocol_id.value));				
		}
		return protocolId;
	}

	bioassays.getParents = function()
	{
		var frm = document.forms['rawbioassay'];
		var parents = [];

		var bioAssayId = Math.abs(parseInt(frm.bioassay_id.value));
		if (bioAssayId > 0) parents[parents.length] = 'DERIVEDBIOASSAY:'+bioAssayId;
		var extractId = Math.abs(parseInt(frm.extract_id.value));
		if (extractId > 0) parents[parents.length] = 'EXTRACT:'+extractId;
		var softwareId = Math.abs(parseInt(frm.software_id.value));
		if (softwareId > 0) parents[parents.length] = 'SOFTWARE:'+softwareId;
		if (frm.arraydesign_id)
		{
			var arrayDesignId = Math.abs(parseInt(frm.arraydesign_id.value));
			if (arrayDesignId > 0) parents[parents.length] = 'ARRAYDESIGN:'+arrayDesignId;
		}
		return parents;
	}

	bioassays.platformOnChange = function()
	{
		var frm = document.forms['rawbioassay'];
		var selected = frm.platform[frm.platform.selectedIndex];
		var platform = Data.get(selected, 'platform');
		var variant = Data.get(selected, 'variant');
		var fileOnly = Data.int(selected, 'file-only');
		var rawDataType = Data.get(selected, 'raw-data-type');

		if (frm.rawdatatype[frm.rawdatatype.length - 1].value == '')
		{
			frm.rawdatatype[frm.rawdatatype.length - 1] = null;
		}
		if (fileOnly)
		{
			frm.rawdatatype.disabled = true;
			Doc.removeClass(frm.rawdatatype, 'required');
			frm.rawdatatype[frm.rawdatatype.length] = new Option('- file only -', '');
			frm.rawdatatype.selectedIndex = frm.rawdatatype.length - 1;
		}
		else if (rawDataType)
		{
			frm.rawdatatype.disabled = true;
			Doc.removeClass(frm.rawdatatype, 'required');
			Forms.selectListOption(frm.rawdatatype, rawDataType);
		}
		else
		{
			frm.rawdatatype.disabled = Data.int('page-data', 'has-db-spots');
			Doc.addClass(frm.rawdatatype, 'required');
		}
	}

	
	bioassays.selectProtocol = function()
	{
		var frm = document.forms['rawbioassay'];
		var url = '&resetTemporary=1';
		url += '&tmpfilter:INT:itemSubtype='+Data.get('page-data', 'feature-extraction-protocol');
		if (frm.protocol_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.protocol_id[1].value));				
			url += '&item_id='+id;
		}
		Dialogs.selectItem('PROTOCOL', 'protocol_id', 0, url);
	}
	
	bioassays.setProtocolCallback = function(event)
	{
		var frm = document.forms['rawbioassay'];
		var list = frm.protocol_id;
		if (list.length < 2 || list[1].value == '0')
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
	}

	bioassays.selectSoftware = function()
	{
		var frm = document.forms['rawbioassay'];
		var url = '&resetTemporary=1';
		url += '&tmpfilter:INT:itemSubtype='+Data.get('page-data', 'feature-extraction-software');
		if (frm.software_id.length > 1)
		{
			var id = Math.abs(parseInt(frm.software_id[1].value));				
			url += '&item_id='+id;
		}
		Dialogs.selectItem('SOFTWARE', 'software_id', 0, url);
	}
	
	bioassays.setSoftwareCallback = function(event)
	{
		var frm = document.forms['rawbioassay'];
		var list = frm.software_id;
		if (list.length < 2 || list[1].value == '0')
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
	}

	bioassays.selectBioAssay = function()
	{
		var frm = document.forms['rawbioassay'];
		var url = '&resetTemporary=1';
		if (frm.bioassay_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.bioassay_id[1].value));
			url += '&item_id='+id;
		}
		Dialogs.selectItem('DERIVEDBIOASSAY', 'bioassay_id', 0, url);
	}
	
	bioassays.setBioAssayCallback = function(event)
	{
		var frm = document.forms['rawbioassay'];
		var list = frm.bioassay_id;
		if (list.length < 2 || list[1].value == '0')
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
		bioassays.bioAssayOnChange();
	}

	bioassays.bioAssayOnChange = function()
	{
		var frm = document.forms['rawbioassay'];
		var bioAssayId = Math.abs(frm.bioassay_id.value);
		if (bioAssayId > 0) bioassays.updateArrayDesign(bioAssayId);
	}
	
	bioassays.updateArrayDesign = function(bioAssayId)
	{
		if (!bioAssayId) return;
		var request = Ajax.getXmlHttpRequest();
		var url = '../derivedbioassays/ajax.jsp?ID='+App.getSessionId();
		url += '&cmd=GetArrayDesign&item_id=' + bioAssayId;
		request.open("GET", url, false);
		request.send(null);

		var response = JSON.parse(request.responseText);
		if (response.status != 'ok')
		{
			alert(response.message);
			return null;
		}
		
		var frm = document.forms['rawbioassay'];
		if (response.id)
		{
			var designList = frm.arraydesign_id;
			if (designList.length < 2 || designList[1].value == '0')
			{
				Forms.addListOption(designList, 1, new Option());
			}
			designList[1].value = response.id;
			designList[1].text = response.name;
			designList.selectedIndex = 1;
			bioassays.arrayDesignOnChange();
		}
	}

	bioassays.selectArrayDesign = function()
	{
		var frm = document.forms['rawbioassay'];
		var url = '&resetTemporary=1';
		if (frm.arraydesign_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.arraydesign_id[1].value));				
			url += '&item_id='+id;
		}
		
		var platform = frm.platform[frm.platform.selectedIndex];
		var platformId = Data.get(platform, 'platform');
		var variantId = Data.get(platform, 'variant');
		url += '&tmpfilter:INT:platform='+platformId;
		if (variantId) url += '&tmpfilter:INT:variant='+variantId;
		Dialogs.selectItem('ARRAYDESIGN', 'arraydesign_id', 0, url);
	}
	
	bioassays.setArrayDesignCallback = function(event)
	{
		var frm = document.forms['rawbioassay'];
		var list = frm.arraydesign_id;
		if (list.length < 2 || list[1].value == '0')
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
		bioassays.arrayDesignOnChange();
	}

	bioassays.arrayDesignOnChange = function()
	{
		if (Data.int('page-data', 'has-db-spots'))
		{
			var oldArrayDesign = Data.get('arraydesign_id', 'current-array-design');
			var frm = document.forms['rawbioassay'];
			var selectedId = frm.arraydesign_id.value;
			var showFiMethod = (selectedId > 0 && selectedId != oldArrayDesign);
			if (showFiMethod)
			{
				Doc.show('fiMethod');
			}
			else
			{
				Doc.hide('fiMethod');
			}
		}
	}

	bioassays.selectExtract = function()
	{
		var frm = document.forms['rawbioassay'];
		
		var relatedExtractIds = null;
		var bioAssayId = Math.abs(frm.bioassay_id.value);
		if (bioAssayId > 0)
		{
			var request = Ajax.getXmlHttpRequest();
			var url = '../derivedbioassays/ajax.jsp?ID='+App.getSessionId();
			url += '&cmd=GetAllExtractIds&bioassay_ids=' + bioAssayId;
			request.open("GET", url, false); 
			request.send(null);
									
			var response = JSON.parse(request.responseText);
			if (response.status != 'ok')
			{
				alert(response.message);
				return null;
			}
			relatedExtractIds = response.allExtractIds;
		}
		
		var url = '&resetTemporary=1';
		if (relatedExtractIds) 
		{
			url += '&tmpfilter:INT:id='+relatedExtractIds.join('|');
		}
		if (frm.extract_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.extract_id[1].value));
			url += '&item_id='+id;
		}
		Dialogs.selectItem('EXTRACT', 'extract_id', 0, url);
	}
	
	bioassays.setExtractCallback = function(event)
	{
		var frm = document.forms['rawbioassay'];
		var list = frm.extract_id;
		if (list.length < 2 || list[1].value == '0')
		{
			Forms.addListOption(list, 1, new Option());
		}
		list[1].value = event.detail.id;
		list[1].text = event.detail.name;
		list.selectedIndex = 1;
	}

	
	return bioassays;
}();

Doc.onLoad(BioAssays.initPage);

